@@ -346,32 +346,26 @@ class legacy_function(object):
     @late
     def crc32(self):
         try:
-        
             from zlib import crc32
-            try:
-                if crc32('amuse')&0xffffffff == 0xc0cc9367:
-                    return crc32
-            except Exception:
-                #python 3, crc32 needs bytes...
-                def python3_crc32(x):
-                    x = crc32(bytes(x, 'ascii'))
-                    return x - ((x & 0x80000000) <<1)
-                if python3_crc32('amuse')&0xffffffff == 0xc0cc9367:
-                    return python3_crc32
+            # python 3, crc32 needs bytes...
+
+            def python3_crc32(x):
+                x = crc32(bytes(x, 'ascii'))
+                return x - ((x & 0x80000000) << 1)
+
+            if python3_crc32('amuse') & 0xffffffff == 0xc0cc9367:
+                return python3_crc32
         except Exception:
             pass
         try:
             from binascii import crc32
-            try:
-                if crc32('amuse')&0xffffffff == 0xc0cc9367:
-                    return crc32
-            except Exception:
-                #python 3, crc32 needs bytes...
-                def python3_crc32(x):
-                    x = crc32(bytes(x, 'ascii'))
-                    return x - ((x & 0x80000000) <<1)
-                if python3_crc32('amuse')&0xffffffff == 0xc0cc9367:
-                    return python3_crc32
+            # python 3, crc32 needs bytes...
+
+            def python3_crc32(x):
+                x = crc32(bytes(x, 'ascii'))
+                return x - ((x & 0x80000000) << 1)
+            if python3_crc32('amuse') & 0xffffffff == 0xc0cc9367:
+                return python3_crc32
         except Exception:
             pass
         
@@ -451,7 +445,7 @@ def get_function_specification(name,in_arg,out_arg,must_handle_array=False,
   
 def simplified_function_specification(must_handle_array=False,can_handle_array=False):
     def wrapper(f):
-        argspec=inspect.getargspec(f)
+        argspec=inspect.getfullargspec(f)
         nkw=len(argspec.defaults) if argspec.defaults else 0
         defaults=argspec.defaults if argspec.defaults else []
         length_arguments=argspec.args[0:-nkw]
